@@ -16,7 +16,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from collections import Sequence
+import collections
 import functools
 
 from django.conf import settings
@@ -25,6 +25,15 @@ import six
 
 from horizon import exceptions
 
+# Python 3.8 removes the ability to import the abstract base classes from
+# 'collections', but 'collections.abc' is not present in Python 2.7
+# TODO(stephenfin): Remove when we drop support for Python 2.7
+# pylint: disable=ungrouped-imports
+if hasattr(collections, 'abc'):
+    from collections.abc import Sequence
+else:
+    from collections import Sequence
+
 
 __all__ = ('APIResourceWrapper', 'APIDictWrapper',
            'get_service_from_catalog', 'url_for',)
@@ -32,30 +41,50 @@ __all__ = ('APIResourceWrapper', 'APIDictWrapper',
 
 @functools.total_ordering
 class Version(object):
+    """A class to handle API version.
+
+    The current OpenStack APIs use the versioning of "<major>.<minor>",
+    so this class supports this style only.
+    """
+    # NOTE(amotoki): The implementation depends on the semantic_version library
+    # but we don't care the patch version in this class.
+
     def __init__(self, version):
-        self.version = semantic_version.Version(str(version), partial=True)
+        # NOTE(amotoki):
+        # All comparisons should use self.sem_ver as we would like to
+        # compare versions in the semantic versioning way.
+        # self.orig_ver should be used only in __str__ and __repr__
+        # to keep the original version information.
+        self.orig_ver = str(version)
+        self.sem_ver = semantic_version.Version.coerce(str(version))
+
+    @property
+    def major(self):
+        return self.sem_ver.major
+
+    @property
+    def minor(self):
+        return self.sem_ver.minor
 
     def __eq__(self, other):
-        return self.version == Version(other).version
+        return self.sem_ver == Version(other).sem_ver
 
     def __lt__(self, other):
-        return self.version < Version(other).version
+        return self.sem_ver < Version(other).sem_ver
 
     def __repr__(self):
-        return "Version('%s')" % self.version
+        return "Version('%s')" % self.orig_ver
 
     def __str__(self):
-        return str(self.version)
+        return str(self.orig_ver)
 
     def __hash__(self):
-        return hash(str(self.version))
+        return hash(str(self.sem_ver))
 
 
 class APIVersionManager(object):
     """Object to store and manage API versioning data and utility methods."""
 
-    SETTINGS_KEY = "OPENSTACK_API_VERSIONS"
-
     def __init__(self, service_type, preferred_version=None):
         self.service_type = service_type
         self.preferred = preferred_version
@@ -82,7 +111,7 @@ class APIVersionManager(object):
     def get_active_version(self):
         if self._active is not None:
             return self.supported[self._active]
-        key = getattr(settings, self.SETTINGS_KEY, {}).get(self.service_type)
+        key = settings.OPENSTACK_API_VERSIONS.get(self.service_type)
         if key is None:
             # TODO(gabriel): support API version discovery here; we'll leave
             # the setting in as a way of overriding the latest available
@@ -324,10 +353,8 @@ def get_url_for_service(service, region, endpoint_type):
 
 
 def url_for(request, service_type, endpoint_type=None, region=None):
-    endpoint_type = endpoint_type or getattr(settings,
-                                             'OPENSTACK_ENDPOINT_TYPE',
-                                             'publicURL')
-    fallback_endpoint_type = getattr(settings, 'SECONDARY_ENDPOINT_TYPE', None)
+    endpoint_type = endpoint_type or settings.OPENSTACK_ENDPOINT_TYPE
+    fallback_endpoint_type = settings.SECONDARY_ENDPOINT_TYPE
 
     catalog = request.user.service_catalog
     service = get_service_from_catalog(catalog, service_type)
