@@ -34,10 +34,19 @@ import glanceclient as glance_client
 import six
 from six.moves import _thread as thread
 
-from horizon.utils import functions as utils
 from horizon.utils.memoized import memoized
 from openstack_dashboard.api import base
 from openstack_dashboard.contrib.developer.profiler import api as profiler
+from openstack_dashboard.utils import settings as utils
+
+# Python 3.8 removes the ability to import the abstract base classes from
+# 'collections', but 'collections.abc' is not present in Python 2.7
+# TODO(stephenfin): Remove when we drop support for Python 2.7
+# pylint: disable=ungrouped-imports
+if hasattr(collections, 'abc'):
+    from collections.abc import Iterable
+else:
+    from collections import Iterable
 
 
 LOG = logging.getLogger(__name__)
@@ -125,7 +134,7 @@ class Image(base.APIResourceWrapper):
         # for v2), self._apiresource is not iterable. In that case,
         # the properties are included in the apiresource dict, so
         # just return that dict.
-        if not isinstance(self._apiresource, collections.Iterable):
+        if not isinstance(self._apiresource, Iterable):
             return self._apiresource.to_dict()
         image_dict = super(Image, self).to_dict()
         image_dict['is_public'] = self.is_public
@@ -146,8 +155,8 @@ def glanceclient(request, version=None):
     api_version = VERSIONS.get_active_version()
 
     url = base.url_for(request, 'image')
-    insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
-    cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
+    insecure = settings.OPENSTACK_SSL_NO_VERIFY
+    cacert = settings.OPENSTACK_SSL_CACERT
 
     # TODO(jpichon): Temporarily keep both till we update the API calls
     # to stop hardcoding a version in this file. Once that's done we
@@ -329,7 +338,7 @@ def image_list_detailed(request, marker=None, sort_dir='desc',
         Set this flag to True when it's necessary to get a reversed list of
         images from Glance (used for navigating the images list back in UI).
     """
-    limit = getattr(settings, 'API_RESULT_LIMIT', 1000)
+    limit = settings.API_RESULT_LIMIT
     page_size = utils.get_page_size(request)
 
     if paginate:
@@ -412,7 +421,7 @@ def image_update(request, image_id, **kwargs):
 
 
 def get_image_upload_mode():
-    mode = getattr(settings, 'HORIZON_IMAGES_UPLOAD_MODE', 'legacy')
+    mode = settings.HORIZON_IMAGES_UPLOAD_MODE
     if mode not in ('off', 'legacy', 'direct'):
         LOG.warning('HORIZON_IMAGES_UPLOAD_MODE has an unrecognized value of '
                     '"%s", reverting to default "legacy" value', mode)
@@ -472,6 +481,10 @@ def create_image_metadata(data):
         # 'raw' as the disk format and 'docker' as the container format.
         meta['disk_format'] = 'raw'
         meta['container_format'] = 'docker'
+    elif meta['disk_format'] == 'vhd':
+        # If the user wishes to upload a vhd using Horizon, then
+        # 'ovf' must be the container format
+        meta['container_format'] = 'ovf'
     elif meta['disk_format'] == 'ova':
         # If the user wishes to upload an OVA using Horizon, then
         # 'ova' must be the container format and 'vmdk' must be the disk
@@ -701,7 +714,7 @@ def metadefs_namespace_list(request,
 
     if filters is None:
         filters = {}
-    limit = getattr(settings, 'API_RESULT_LIMIT', 1000)
+    limit = settings.API_RESULT_LIMIT
     page_size = utils.get_page_size(request)
 
     if paginate:
