@@ -33,18 +33,16 @@ from openstack_auth import backend
 from openstack_auth import utils as auth_utils
 
 from horizon import exceptions
-from horizon import messages
-from horizon.utils import functions as utils
 
 from openstack_dashboard.api import base
 from openstack_dashboard.contrib.developer.profiler import api as profiler
 from openstack_dashboard import policy
+from openstack_dashboard.utils import settings as setting_utils
 
 
 LOG = logging.getLogger(__name__)
 DEFAULT_ROLE = None
-DEFAULT_DOMAIN = getattr(settings, 'OPENSTACK_KEYSTONE_DEFAULT_DOMAIN',
-                         'Default')
+DEFAULT_DOMAIN = settings.OPENSTACK_KEYSTONE_DEFAULT_DOMAIN
 
 
 # Set up our data structure for managing Identity API versions, and
@@ -57,25 +55,13 @@ class IdentityAPIVersionManager(base.APIVersionManager):
         return user
 
     def get_project_manager(self, *args, **kwargs):
-        if VERSIONS.active < 3:
-            manager = keystoneclient(*args, **kwargs).tenants
-        else:
-            manager = keystoneclient(*args, **kwargs).projects
-        return manager
+        return keystoneclient(*args, **kwargs).projects
 
 
 VERSIONS = IdentityAPIVersionManager(
     "identity", preferred_version=auth_utils.get_keystone_version())
 
 
-# Import from oldest to newest so that "preferred" takes correct precedence.
-try:
-    # pylint: disable=ungrouped-imports
-    from keystoneclient.v2_0 import client as keystone_client_v2
-    VERSIONS.load_supported_version(2.0, {"client": keystone_client_v2})
-except ImportError:
-    pass
-
 try:
     # pylint: disable=ungrouped-imports
     from keystoneclient.v3 import client as keystone_client_v3
@@ -121,7 +107,7 @@ def _get_endpoint_url(request, endpoint_type, catalog=None):
                    "Keystone endpoint, but v3 is specified as the API version "
                    "to use by Horizon. Using v3 endpoint for authentication.")
     else:
-        auth_url = getattr(settings, 'OPENSTACK_KEYSTONE_URL')
+        auth_url = settings.OPENSTACK_KEYSTONE_URL
         url = request.session.get('region_endpoint', auth_url)
         message = ("The OPENSTACK_KEYSTONE_URL setting points to a v2.0 "
                    "Keystone endpoint, but v3 is specified as the API version "
@@ -178,9 +164,7 @@ def keystoneclient(request, admin=False):
             raise exceptions.NotAuthorized
         endpoint_type = 'adminURL'
     else:
-        endpoint_type = getattr(settings,
-                                'OPENSTACK_ENDPOINT_TYPE',
-                                'publicURL')
+        endpoint_type = settings.OPENSTACK_ENDPOINT_TYPE
 
     # Take care of client connection caching/fetching a new client.
     # Admin vs. non-admin clients are cached separately for token matching.
@@ -192,8 +176,8 @@ def keystoneclient(request, admin=False):
         conn = getattr(request, cache_attr)
     else:
         endpoint = _get_endpoint_url(request, endpoint_type)
-        verify = not getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
-        cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
+        verify = not settings.OPENSTACK_SSL_NO_VERIFY
+        cacert = settings.OPENSTACK_SSL_CACERT
         verify = verify and cacert
         LOG.debug("Creating a new keystoneclient connection to %s.", endpoint)
         remote_addr = request.environ.get('REMOTE_ADDR', '')
@@ -273,12 +257,9 @@ def tenant_create(request, name, description=None, enabled=None,
                   domain=None, **kwargs):
     manager = VERSIONS.get_project_manager(request, admin=True)
     try:
-        if VERSIONS.active < 3:
-            return manager.create(name, description, enabled, **kwargs)
-        else:
-            return manager.create(name, domain,
-                                  description=description,
-                                  enabled=enabled, **kwargs)
+        return manager.create(name, domain,
+                              description=description,
+                              enabled=enabled, **kwargs)
     except keystone_exceptions.Conflict:
         raise exceptions.Conflict()
 
@@ -371,25 +352,13 @@ def tenant_delete(request, project):
 def tenant_list(request, paginate=False, marker=None, domain=None, user=None,
                 admin=True, filters=None):
     manager = VERSIONS.get_project_manager(request, admin=admin)
-    page_size = utils.get_page_size(request)
     tenants = []
-    limit = None
-    if paginate:
-        limit = page_size + 1
-
     has_more_data = False
 
     # if requesting the projects for the current user,
     # return the list from the cache
     if user == request.user.id:
         tenants = request.user.authorized_tenants
-
-    elif VERSIONS.active < 3:
-        tenants = manager.list(limit, marker)
-        if paginate and len(tenants) > page_size:
-            tenants.pop(-1)
-            has_more_data = True
-    # V3 API
     else:
         domain_id = get_effective_domain_id(request)
         kwargs = {
@@ -415,12 +384,8 @@ def tenant_update(request, project, name=None, description=None,
                   enabled=None, domain=None, **kwargs):
     manager = VERSIONS.get_project_manager(request, admin=True)
     try:
-        if VERSIONS.active < 3:
-            return manager.update(project, name, description, enabled,
-                                  **kwargs)
-        else:
-            return manager.update(project, name=name, description=description,
-                                  enabled=enabled, domain=domain, **kwargs)
+        return manager.update(project, name=name, description=description,
+                              enabled=enabled, domain=domain, **kwargs)
     except keystone_exceptions.Conflict:
         raise exceptions.Conflict()
 
@@ -428,16 +393,13 @@ def tenant_update(request, project, name=None, description=None,
 @profiler.trace
 def user_list(request, project=None, domain=None, group=None, filters=None):
     users = []
-    if VERSIONS.active < 3:
-        kwargs = {"tenant_id": project}
-    else:
-        kwargs = {
-            "project": project,
-            "domain": domain,
-            "group": group
-        }
-        if filters is not None:
-            kwargs.update(filters)
+    kwargs = {
+        "project": project,
+        "domain": domain,
+        "group": group
+    }
+    if filters is not None:
+        kwargs.update(filters)
     if 'id' in kwargs:
         try:
             users = [user_get(request, kwargs['id'])]
@@ -453,14 +415,10 @@ def user_create(request, name=None, email=None, password=None, project=None,
                 enabled=None, domain=None, description=None, **data):
     manager = keystoneclient(request, admin=True).users
     try:
-        if VERSIONS.active < 3:
-            user = manager.create(name, password, email, project, enabled)
-            return VERSIONS.upgrade_v2_user(user)
-        else:
-            return manager.create(name, password=password, email=email,
-                                  default_project=project, enabled=enabled,
-                                  domain=domain, description=description,
-                                  **data)
+        return manager.create(name, password=password, email=email,
+                              default_project=project, enabled=enabled,
+                              domain=domain, description=description,
+                              **data)
     except keystone_exceptions.Conflict:
         raise exceptions.Conflict()
 
@@ -479,59 +437,20 @@ def user_get(request, user_id, admin=True):
 @profiler.trace
 def user_update(request, user, **data):
     manager = keystoneclient(request, admin=True).users
-    error = None
 
     if not keystone_can_edit_user():
         raise keystone_exceptions.ClientException(
             405, _("Identity service does not allow editing user data."))
-
-    # The v2 API updates user model and default project separately
-    if VERSIONS.active < 3:
-        # Update user details
-        try:
-            user = manager.update(user, **data)
-        except keystone_exceptions.Conflict:
-            raise exceptions.Conflict()
-        except Exception:
-            error = exceptions.handle(request, ignore=True)
-
-        if "project" in data:
-            project = data.pop('project')
-
-            # Update default tenant
-            try:
-                user_update_tenant(request, user, project)
-                user.tenantId = project
-            except Exception:
-                error = exceptions.handle(request, ignore=True)
-
-            # Check for existing roles
-            # Show a warning if no role exists for the project
-            user_roles = roles_for_user(request, user, project)
-            if not user_roles:
-                messages.warning(request,
-                                 _('User %s has no role defined for '
-                                   'that project.')
-                                 % data.get('name', None))
-
-        if error is not None:
-            raise error
-
-    # v3 API is so much simpler...
-    else:
-        try:
-            user = manager.update(user, **data)
-        except keystone_exceptions.Conflict:
-            raise exceptions.Conflict()
+    try:
+        user = manager.update(user, **data)
+    except keystone_exceptions.Conflict:
+        raise exceptions.Conflict()
 
 
 @profiler.trace
 def user_update_enabled(request, user, enabled):
     manager = keystoneclient(request, admin=True).users
-    if VERSIONS.active < 3:
-        manager.update_enabled(user, enabled)
-    else:
-        manager.update(user, enabled=enabled)
+    manager.update(user, enabled=enabled)
 
 
 @profiler.trace
@@ -542,20 +461,17 @@ def user_update_password(request, user, password, admin=True):
             405, _("Identity service does not allow editing user password."))
 
     manager = keystoneclient(request, admin=admin).users
-    if VERSIONS.active < 3:
-        manager.update_password(user, password)
-    else:
-        manager.update(user, password=password)
+    manager.update(user, password=password)
 
 
 def user_verify_admin_password(request, admin_password):
     # attempt to create a new client instance with admin password to
     # verify if it's correct.
-    client = keystone_client_v2 if VERSIONS.active < 3 else keystone_client_v3
+    client = keystone_client_v3
     try:
         endpoint = _get_endpoint_url(request, 'publicURL')
-        insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
-        cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
+        insecure = settings.OPENSTACK_SSL_NO_VERIFY
+        cacert = settings.OPENSTACK_SSL_CACERT
         client.Client(
             username=request.user.username,
             password=admin_password,
@@ -572,21 +488,14 @@ def user_verify_admin_password(request, admin_password):
 @profiler.trace
 def user_update_own_password(request, origpassword, password):
     client = keystoneclient(request, admin=False)
-    if VERSIONS.active < 3:
-        client.user_id = request.user.id
-        return client.users.update_own_password(origpassword, password)
-    else:
-        client.users.client.session.auth.user_id = request.user.id
-        return client.users.update_password(origpassword, password)
+    client.users.client.session.auth.user_id = request.user.id
+    return client.users.update_password(origpassword, password)
 
 
 @profiler.trace
 def user_update_tenant(request, user, project, admin=True):
     manager = keystoneclient(request, admin=admin).users
-    if VERSIONS.active < 3:
-        return manager.update_tenant(user, project)
-    else:
-        return manager.update(user, project=project)
+    return manager.update(user, project=project)
 
 
 @profiler.trace
@@ -696,9 +605,6 @@ def get_project_groups_roles(request, project):
 def role_assignments_list(request, project=None, user=None, role=None,
                           group=None, domain=None, effective=False,
                           include_subtree=True, include_names=False):
-    if VERSIONS.active < 3:
-        raise exceptions.NotAvailable
-
     if include_subtree:
         domain = None
 
@@ -758,10 +664,7 @@ def role_list(request, filters=None):
 def roles_for_user(request, user, project=None, domain=None):
     """Returns a list of user roles scoped to a project or domain."""
     manager = keystoneclient(request, admin=True).roles
-    if VERSIONS.active < 3:
-        return manager.roles_for_user(user, project)
-    else:
-        return manager.list(user=user, domain=domain, project=project)
+    return manager.list(user=user, domain=domain, project=project)
 
 
 @profiler.trace
@@ -800,26 +703,18 @@ def remove_domain_user_role(request, user, role, domain=None):
 @profiler.trace
 def get_project_users_roles(request, project):
     users_roles = collections.defaultdict(list)
-    if VERSIONS.active < 3:
-        project_users = user_list(request, project=project)
+    project_role_assignments = role_assignments_list(request,
+                                                     project=project)
+    for role_assignment in project_role_assignments:
+        if not hasattr(role_assignment, 'user'):
+            continue
+        user_id = role_assignment.user['id']
+        role_id = role_assignment.role['id']
 
-        for user in project_users:
-            roles = roles_for_user(request, user.id, project)
-            roles_ids = [role.id for role in roles]
-            users_roles[user.id].extend(roles_ids)
-    else:
-        project_role_assignments = role_assignments_list(request,
-                                                         project=project)
-        for role_assignment in project_role_assignments:
-            if not hasattr(role_assignment, 'user'):
-                continue
-            user_id = role_assignment.user['id']
-            role_id = role_assignment.role['id']
-
-            # filter by project_id
-            if ('project' in role_assignment.scope and
-                    role_assignment.scope['project']['id'] == project):
-                users_roles[user_id].append(role_id)
+        # filter by project_id
+        if ('project' in role_assignment.scope and
+                role_assignment.scope['project']['id'] == project):
+            users_roles[user_id].append(role_id)
     return users_roles
 
 
@@ -828,11 +723,8 @@ def add_tenant_user_role(request, project=None, user=None, role=None,
                          group=None, domain=None):
     """Adds a role for a user on a tenant."""
     manager = keystoneclient(request, admin=True).roles
-    if VERSIONS.active < 3:
-        manager.add_user_role(user, role, project)
-    else:
-        manager.grant(role, user=user, project=project,
-                      group=group, domain=domain)
+    manager.grant(role, user=user, project=project,
+                  group=group, domain=domain)
 
 
 @profiler.trace
@@ -840,11 +732,8 @@ def remove_tenant_user_role(request, project=None, user=None, role=None,
                             group=None, domain=None):
     """Removes a given single role for a user from a tenant."""
     manager = keystoneclient(request, admin=True).roles
-    if VERSIONS.active < 3:
-        return manager.remove_user_role(user, role, project)
-    else:
-        return manager.revoke(role, user=user, project=project,
-                              group=group, domain=domain)
+    return manager.revoke(role, user=user, project=project,
+                          group=group, domain=domain)
 
 
 def remove_tenant_user(request, project=None, user=None, domain=None):
@@ -895,7 +784,7 @@ def get_default_role(request):
     to request. Supports lookup by name or id.
     """
     global DEFAULT_ROLE
-    default = getattr(settings, "OPENSTACK_KEYSTONE_DEFAULT_ROLE", None)
+    default = settings.OPENSTACK_KEYSTONE_DEFAULT_ROLE
     if default and DEFAULT_ROLE is None:
         try:
             roles = keystoneclient(request, admin=True).roles.list()
@@ -914,9 +803,8 @@ def ec2_manager(request):
     if hasattr(client, 'ec2'):
         return client.ec2
 
-    # Keystoneclient 4.0 was released without the ec2 creds manager.
-    from keystoneclient.v2_0 import ec2
-    return ec2.CredentialsManager(client)
+    from keystoneclient.v3 import ec2
+    return ec2.EC2Manager(client)
 
 
 @profiler.trace
@@ -940,39 +828,35 @@ def delete_user_ec2_credentials(request, user_id, access_token):
 
 
 def keystone_can_edit_domain():
-    backend_settings = getattr(settings, "OPENSTACK_KEYSTONE_BACKEND", {})
-    can_edit_domain = backend_settings.get('can_edit_domain', True)
-    multi_domain_support = getattr(settings,
-                                   'OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT',
-                                   False)
+    can_edit_domain = setting_utils.get_dict_config(
+        'OPENSTACK_KEYSTONE_BACKEND', 'can_edit_domain')
+    multi_domain_support = settings.OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT
     return can_edit_domain and multi_domain_support
 
 
 def keystone_can_edit_user():
-    backend_settings = getattr(settings, "OPENSTACK_KEYSTONE_BACKEND", {})
-    return backend_settings.get('can_edit_user', True)
+    return setting_utils.get_dict_config(
+        'OPENSTACK_KEYSTONE_BACKEND', 'can_edit_user')
 
 
 def keystone_can_edit_project():
-    backend_settings = getattr(settings, "OPENSTACK_KEYSTONE_BACKEND", {})
-    return backend_settings.get('can_edit_project', True)
+    return setting_utils.get_dict_config(
+        'OPENSTACK_KEYSTONE_BACKEND', 'can_edit_project')
 
 
 def keystone_can_edit_group():
-    backend_settings = getattr(settings, "OPENSTACK_KEYSTONE_BACKEND", {})
-    return backend_settings.get('can_edit_group', True)
+    return setting_utils.get_dict_config(
+        'OPENSTACK_KEYSTONE_BACKEND', 'can_edit_group')
 
 
 def keystone_can_edit_role():
-    backend_settings = getattr(settings, "OPENSTACK_KEYSTONE_BACKEND", {})
-    return backend_settings.get('can_edit_role', True)
+    return setting_utils.get_dict_config(
+        'OPENSTACK_KEYSTONE_BACKEND', 'can_edit_role')
 
 
 def keystone_backend_name():
-    if hasattr(settings, "OPENSTACK_KEYSTONE_BACKEND"):
-        return settings.OPENSTACK_KEYSTONE_BACKEND['name']
-    else:
-        return 'unknown'
+    return setting_utils.get_dict_config(
+        'OPENSTACK_KEYSTONE_BACKEND', 'name') or 'unknown'
 
 
 def get_version():
@@ -981,11 +865,11 @@ def get_version():
 
 def is_multi_domain_enabled():
     return (VERSIONS.active >= 3 and
-            getattr(settings, 'OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT', False))
+            settings.OPENSTACK_KEYSTONE_MULTIDOMAIN_SUPPORT)
 
 
 def is_federation_management_enabled():
-    return getattr(settings, 'OPENSTACK_KEYSTONE_FEDERATION_MANAGEMENT', False)
+    return settings.OPENSTACK_KEYSTONE_FEDERATION_MANAGEMENT
 
 
 def identity_provider_create(request, idp_id, description=None,
