@@ -39,6 +39,16 @@ from openstack_dashboard.api import base
 from openstack_dashboard.api import nova
 from openstack_dashboard.contrib.developer.profiler import api as profiler
 from openstack_dashboard import policy
+from openstack_dashboard.utils import settings as setting_utils
+
+# Python 3.8 removes the ability to import the abstract base classes from
+# 'collections', but 'collections.abc' is not present in Python 2.7
+# TODO(stephenfin): Remove when we drop support for Python 2.7
+# pylint: disable=ungrouped-imports
+if hasattr(collections, 'abc'):
+    from collections.abc import Sequence
+else:
+    from collections import Sequence
 
 
 LOG = logging.getLogger(__name__)
@@ -672,7 +682,7 @@ class FloatingIpManager(object):
                                       {'floatingip': update_dict})
 
     def _get_reachable_subnets(self, ports, fetch_router_ports=False):
-        if not is_enabled_by_config('enable_fip_topology_check', True):
+        if not is_enabled_by_config('enable_fip_topology_check'):
             # All subnets are reachable from external network
             return set(
                 p.fixed_ips[0]['subnet_id'] for p in ports if p.fixed_ips
@@ -790,8 +800,8 @@ class FloatingIpManager(object):
 
     def is_supported(self):
         """Returns True if floating IP feature is supported."""
-        network_config = getattr(settings, 'OPENSTACK_NEUTRON_NETWORK', {})
-        return network_config.get('enable_router', True)
+        return setting_utils.get_dict_config(
+            'OPENSTACK_NEUTRON_NETWORK', 'enable_router')
 
 
 def get_ipver_str(ip_version):
@@ -810,8 +820,8 @@ def get_auth_params_from_request(request):
 @memoized
 def neutronclient(request):
     token_id, neutron_url, auth_url = get_auth_params_from_request(request)
-    insecure = getattr(settings, 'OPENSTACK_SSL_NO_VERIFY', False)
-    cacert = getattr(settings, 'OPENSTACK_SSL_CACERT', None)
+    insecure = settings.OPENSTACK_SSL_NO_VERIFY
+    cacert = settings.OPENSTACK_SSL_CACERT
     c = neutron_client.Client(token=token_id,
                               auth_url=auth_url,
                               endpoint_url=neutron_url,
@@ -853,8 +863,11 @@ def list_resources_with_long_filters(list_method,
         # We consider only the filter condition from (filter_attr,
         # filter_values) and do not consider other filter conditions
         # which may be specified in **params.
-        if not isinstance(filter_values, (list, tuple, set, frozenset)):
+
+        if isinstance(filter_values, six.string_types):
             filter_values = [filter_values]
+        elif not isinstance(filter_values, Sequence):
+            filter_values = list(filter_values)
 
         # Length of each query filter is:
         # <key>=<value>& (e.g., id=<uuid>)
@@ -927,7 +940,7 @@ def trunk_update(request, trunk_id, old_trunk, new_trunk):
     trunk. However it should not know anything about how the old and new are
     meant to be diffed and sent to neutron. We handle that here.
 
-    This code was adapted from Heat, see: https://review.openstack.org/442496
+    This code was adapted from Heat, see: https://review.opendev.org/442496
 
     Call #1) Update all changed properties but 'sub_ports'.
         PUT /v2.0/trunks/TRUNK_ID
@@ -1028,7 +1041,7 @@ def _is_auto_allocated_network_supported(request):
     try:
         neutron_auto_supported = is_service_enabled(
             request, 'enable_auto_allocated_network',
-            'auto-allocated-topology', default=False)
+            'auto-allocated-topology')
     except Exception:
         exceptions.handle(request, _('Failed to check if neutron supports '
                                      '"auto_allocated_network".'))
@@ -1825,11 +1838,21 @@ def is_extension_supported(request, extension_alias):
         return False
 
 
+# TODO(amotoki): Clean up 'default' parameter because the default
+# values are pre-defined now, so 'default' argument is meaningless
+# in most cases.
 def is_enabled_by_config(name, default=True):
-    network_config = getattr(settings, 'OPENSTACK_NEUTRON_NETWORK', {})
-    return network_config.get(name, default)
+    try:
+        return setting_utils.get_dict_config('OPENSTACK_NEUTRON_NETWORK', name)
+    except KeyError:
+        # No default value is defined.
+        # This is a fallback logic for horizon plugins.
+        return default
 
 
+# TODO(amotoki): Clean up 'default' parameter because the default
+# values are pre-defined now, so 'default' argument is meaningless
+# in most cases.
 @memoized
 def is_service_enabled(request, config_name, ext_name, default=True):
     return (is_enabled_by_config(config_name, default) and
@@ -1838,7 +1861,7 @@ def is_service_enabled(request, config_name, ext_name, default=True):
 
 @memoized
 def is_quotas_extension_supported(request):
-    return (is_enabled_by_config('enable_quotas', False) and
+    return (is_enabled_by_config('enable_quotas') and
             is_extension_supported(request, 'quotas'))
 
 
@@ -1858,7 +1881,6 @@ FEATURE_MAP = {
         'extension': 'dvr',
         'config': {
             'name': 'enable_distributed_router',
-            'default': False,
         },
         'policies': {
             'get': 'get_router:distributed',
@@ -1868,8 +1890,9 @@ FEATURE_MAP = {
     },
     'l3-ha': {
         'extension': 'l3-ha',
-        'config': {'name': 'enable_ha_router',
-                   'default': False},
+        'config': {
+            'name': 'enable_ha_router',
+        },
         'policies': {
             'get': 'get_router:ha',
             'create': 'create_router:ha',
@@ -1900,7 +1923,6 @@ def get_feature_permission(request, feature, operation=None):
         defined in FEATURE_MAP[feature]['policies']
         It must be specified if FEATURE_MAP[feature] has 'policies'.
     """
-    network_config = getattr(settings, 'OPENSTACK_NEUTRON_NETWORK', {})
     feature_info = FEATURE_MAP.get(feature)
     if not feature_info:
         raise ValueError("The requested feature '%(feature)s' is unknown. "
@@ -1910,8 +1932,8 @@ def get_feature_permission(request, feature, operation=None):
     # Check dashboard settings
     feature_config = feature_info.get('config')
     if feature_config:
-        if not network_config.get(feature_config['name'],
-                                  feature_config['default']):
+        if not setting_utils.get_dict_config('OPENSTACK_NEUTRON_NETWORK',
+                                             feature_config['name']):
             return False
 
     # Check policy
