@@ -11,12 +11,13 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""API for the swift service.
-"""
+"""API for the swift service."""
+
 import os
 
 from django import forms
 from django.http import StreamingHttpResponse
+from django.utils.http import urlunquote
 from django.views.decorators.csrf import csrf_exempt
 from django.views import generic
 import six
@@ -30,46 +31,50 @@ from openstack_dashboard.api import swift
 
 @urls.register
 class Info(generic.View):
-    """API for information about the Swift installation.
-    """
+    """API for information about the Swift installation."""
     url_regex = r'swift/info/$'
 
     @rest_utils.ajax()
     def get(self, request):
-        """Get information about the Swift installation.
-        """
+        """Get information about the Swift installation."""
         capabilities = api.swift.swift_get_capabilities(request)
         return {'info': capabilities}
 
 
 @urls.register
 class Containers(generic.View):
-    """API for swift container listing for an account
-    """
+    """API for swift container listing for an account"""
     url_regex = r'swift/containers/$'
 
     @rest_utils.ajax()
     def get(self, request):
         """Get the list of containers for this account
 
+        :param prefix: container name prefix value. Named items in the
+        response begin with this value
+
         TODO(neillc): Add pagination
         """
-        containers, has_more = api.swift.swift_get_containers(request)
+        prefix = request.GET.get('prefix', None)
+        if prefix:
+            containers, has_more = api.swift.\
+                swift_get_containers(request, prefix=prefix)
+        else:
+            containers, has_more = api.swift.swift_get_containers(request)
+
         containers = [container.to_dict() for container in containers]
         return {'items': containers, 'has_more': has_more}
 
 
 @urls.register
 class Container(generic.View):
-    """API for swift container level information
-    """
+    """API for swift container level information"""
 
     url_regex = r'swift/containers/(?P<container>[^/]+)/metadata/$'
 
     @rest_utils.ajax()
     def get(self, request, container):
-        """Get the container details
-        """
+        """Get the container details"""
         return api.swift.swift_get_container(request, container).to_dict()
 
     @rest_utils.ajax()
@@ -107,8 +112,7 @@ class Container(generic.View):
 
 @urls.register
 class Objects(generic.View):
-    """API for a list of swift objects
-    """
+    """API for a list of swift objects"""
     url_regex = r'swift/containers/(?P<container>[^/]+)/objects/$'
 
     @rest_utils.ajax()
@@ -120,6 +124,8 @@ class Objects(generic.View):
         :return:
         """
         path = request.GET.get('path')
+        if path is not None:
+            path = urlunquote(path)
 
         objects = api.swift.swift_get_objects(
             request,
@@ -146,8 +152,7 @@ class UploadObjectForm(forms.Form):
 
 @urls.register
 class Object(generic.View):
-    """API for a single swift object or pseudo-folder
-    """
+    """API for a single swift object or pseudo-folder"""
     url_regex = r'swift/containers/(?P<container>[^/]+)/object/' \
         '(?P<object_name>.+)$'
 
@@ -207,8 +212,7 @@ class Object(generic.View):
             api.swift.swift_delete_object(request, container, object_name)
 
     def get(self, request, container, object_name):
-        """Get the object contents.
-        """
+        """Get the object contents."""
         obj = api.swift.swift_get_object(
             request,
             container,
@@ -233,8 +237,7 @@ class Object(generic.View):
 
 @urls.register
 class ObjectMetadata(generic.View):
-    """API for a single swift object
-    """
+    """API for a single swift object"""
     url_regex = r'swift/containers/(?P<container>[^/]+)/metadata/' \
         '(?P<object_name>.+)$'
 
@@ -250,8 +253,7 @@ class ObjectMetadata(generic.View):
 
 @urls.register
 class ObjectCopy(generic.View):
-    """API to copy a swift object
-    """
+    """API to copy a swift object"""
     url_regex = r'swift/containers/(?P<container>[^/]+)/copy/' \
         '(?P<object_name>.+)$'
 
