@@ -13,10 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.core.urlresolvers import reverse
 from django.template.defaultfilters import filesizeformat
+from django.urls import reverse
+from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.views.decorators.debug import sensitive_variables
+import six
 
 from horizon import exceptions
 from horizon import forms
@@ -56,9 +58,17 @@ class RebuildInstanceForm(forms.SelfHandlingForm):
         widget=forms.PasswordInput(render_value=False))
     disk_config = forms.ThemableChoiceField(label=_("Disk Partition"),
                                             required=False)
+    description = forms.CharField(
+        label=_("Description"),
+        widget=forms.Textarea(attrs={'rows': 4}),
+        max_length=255,
+        required=False
+    )
 
     def __init__(self, request, *args, **kwargs):
         super(RebuildInstanceForm, self).__init__(request, *args, **kwargs)
+        if not api.nova.is_feature_available(request, "instance_description"):
+            del self.fields['description']
         instance_id = kwargs.get('initial', {}).get('instance_id')
         self.fields['instance_id'].initial = instance_id
 
@@ -105,9 +115,10 @@ class RebuildInstanceForm(forms.SelfHandlingForm):
         image = data.get('image')
         password = data.get('password') or None
         disk_config = data.get('disk_config', None)
+        description = data.get('description', None)
         try:
             api.nova.server_rebuild(request, instance, image, password,
-                                    disk_config)
+                                    disk_config, description=description)
             messages.info(request, _('Rebuilding instance %s.') % instance)
         except Exception:
             redirect = reverse('horizon:project:instances:index')
@@ -183,15 +194,18 @@ class AttachVolume(forms.SelfHandlingForm):
                                          "select a device name."))
     instance_id = forms.CharField(widget=forms.HiddenInput())
 
-    def __init__(self, *args, **kwargs):
-        super(AttachVolume, self).__init__(*args, **kwargs)
+    def __init__(self, request, *args, **kwargs):
+        super(AttachVolume, self).__init__(request, *args, **kwargs)
 
         # Populate volume choices
         volume_list = kwargs.get('initial', {}).get("volume_list", [])
         volumes = []
         for volume in volume_list:
             # Only show volumes that aren't attached to an instance already
-            if not volume.attachments:
+            # Or those with multiattach enabled
+            if (not volume.attachments or
+                    (getattr(volume, 'multiattach', False)) and
+                    api.nova.get_microversion(request, 'multiattach')):
                 volumes.append(
                     (volume.id, '%(name)s (%(id)s)'
                      % {"name": volume.name, "id": volume.id}))
@@ -221,11 +235,15 @@ class AttachVolume(forms.SelfHandlingForm):
                                                    "inst": instance_id,
                                                    "dev": attach.device}
             messages.info(request, message)
-        except Exception:
+        except Exception as ex:
             redirect = reverse('horizon:project:instances:index')
-            exceptions.handle(request,
-                              _('Unable to attach volume.'),
-                              redirect=redirect)
+            if isinstance(ex, api.nova.VolumeMultiattachNotSupported):
+                # Use the specific error from the specific message.
+                msg = six.text_type(ex)
+            else:
+                # Use a generic error message.
+                msg = _('Unable to attach volume: %s') % ex
+            exceptions.handle(request, msg, redirect=redirect)
         return True
 
 
@@ -277,11 +295,11 @@ class DetachVolume(forms.SelfHandlingForm):
                         '%(inst)s.') % {"vol": volume,
                                         "inst": instance_id}
             messages.info(request, message)
-        except Exception:
+        except Exception as ex:
             redirect = reverse('horizon:project:instances:index')
-            exceptions.handle(request,
-                              _("Unable to detach volume."),
-                              redirect=redirect)
+            exceptions.handle(
+                request, _("Unable to detach volume: %s") % ex,
+                redirect=redirect)
         return True
 
 
@@ -299,6 +317,7 @@ class AttachInterface(forms.SelfHandlingForm):
         required=False,
         widget=forms.ThemableSelectWidget(attrs={
             'class': 'switched',
+            'data-required-when-shown': 'true',
             'data-switch-on': 'specification_method',
             'data-specification_method-port': _('Port'),
         }))
@@ -307,6 +326,7 @@ class AttachInterface(forms.SelfHandlingForm):
         required=False,
         widget=forms.ThemableSelectWidget(attrs={
             'class': 'switched',
+            'data-required-when-shown': 'true',
             'data-switch-on': 'specification_method',
             'data-specification_method-network': _('Network'),
         }))
@@ -330,7 +350,7 @@ class AttachInterface(forms.SelfHandlingForm):
 
         choices = [('network', _("by Network (and IP address)"))]
         ports = instance_utils.port_field_data(request, with_network=True)
-        if len(ports) > 0:
+        if ports:
             self.fields['port'].choices = ports
             choices.append(('port', _("by Port")))
 
@@ -407,3 +427,90 @@ class DetachInterface(forms.SelfHandlingForm):
             exceptions.handle(request, _("Unable to detach interface."),
                               redirect=redirect)
         return True
+
+
+class Disassociate(forms.SelfHandlingForm):
+    fip = forms.ThemableChoiceField(label=_('Floating IP'))
+    is_release = forms.BooleanField(label=_('Release Floating IP'),
+                                    required=False)
+
+    def __init__(self, request, *args, **kwargs):
+        super(Disassociate, self).__init__(request, *args, **kwargs)
+        instance_id = self.initial['instance_id']
+        targets = api.neutron.floating_ip_target_list_by_instance(
+            request, instance_id)
+
+        target_ids = [t.port_id for t in targets]
+
+        self.fips = [fip for fip
+                     in api.neutron.tenant_floating_ip_list(request)
+                     if fip.port_id in target_ids]
+
+        fip_choices = [(fip.id, fip.ip) for fip in self.fips]
+        fip_choices.insert(0, ('', _('Select a floating IP to disassociate')))
+        self.fields['fip'].choices = fip_choices
+        self.fields['fip'].initial = self.fips[0].id
+
+    def handle(self, request, data):
+        redirect = reverse_lazy('horizon:project:instances:index')
+        fip_id = data['fip']
+        fips = [fip for fip in self.fips if fip.id == fip_id]
+        if not fips:
+            messages.error(request,
+                           _("The specified floating IP no longer exists."))
+            raise exceptions.Http302(redirect)
+        fip = fips[0]
+        try:
+            if data['is_release']:
+                api.neutron.tenant_floating_ip_release(request, fip_id)
+                messages.success(
+                    request,
+                    _("Successfully disassociated and released "
+                      "floating IP %s") % fip.ip)
+            else:
+                api.neutron.floating_ip_disassociate(request, fip_id)
+                messages.success(
+                    request,
+                    _("Successfully disassociated floating IP %s") % fip.ip)
+        except Exception:
+            exceptions.handle(
+                request,
+                _('Unable to disassociate floating IP %s') % fip.ip,
+                redirect=redirect)
+        return True
+
+
+class RescueInstanceForm(forms.SelfHandlingForm):
+    image = forms.ChoiceField(
+        label=_("Select Image"),
+        widget=forms.ThemableSelectWidget(
+            attrs={'class': 'image-selector'},
+            data_attrs=('size', 'display-name'),
+            transform=_image_choice_title))
+    password = forms.CharField(label=_("Password"), max_length=255,
+                               required=False,
+                               widget=forms.PasswordInput(render_value=False))
+    failure_url = 'horizon:project:instances:index'
+
+    def __init__(self, request, *args, **kwargs):
+        super(RescueInstanceForm, self).__init__(request, *args, **kwargs)
+        images = image_utils.get_available_images(request,
+                                                  request.user.tenant_id)
+        choices = [(image.id, image) for image in images]
+        if not choices:
+            choices.insert(0, ("", _("No images available")))
+        self.fields['image'].choices = choices
+
+    def handle(self, request, data):
+        try:
+            api.nova.server_rescue(request, self.initial["instance_id"],
+                                   password=data["password"],
+                                   image=data["image"])
+            messages.success(request,
+                             _('Successfully rescued instance'))
+            return True
+        except Exception:
+            redirect = reverse(self.failure_url)
+            exceptions.handle(request,
+                              _('Unable to rescue instance'),
+                              redirect=redirect)
