@@ -13,9 +13,10 @@
 #    under the License.
 
 from django import urls
-from django.utils.translation import string_concat
+from django.utils.text import format_lazy
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
+from six.moves.urllib import parse
 
 from horizon import tables
 
@@ -46,7 +47,7 @@ class DeleteKeyPairs(tables.DeleteAction):
         )
 
     def delete(self, request, obj_id):
-        api.nova.keypair_delete(request, obj_id)
+        api.nova.keypair_delete(request, parse.unquote(obj_id))
 
 
 class QuotaKeypairMixin(object):
@@ -56,8 +57,10 @@ class QuotaKeypairMixin(object):
         if usages['key_pairs']['available'] <= 0:
             if "disabled" not in self.classes:
                 self.classes = [c for c in self.classes] + ['disabled']
-                self.verbose_name = string_concat(self.verbose_name, ' ',
-                                                  _("(Quota exceeded)"))
+                self.verbose_name = format_lazy(
+                    '{verbose_name} {quota_exceeded}',
+                    verbose_name=self.verbose_name,
+                    quota_exceeded=_("(Quota exceeded)"))
             return False
         else:
             classes = [c for c in self.classes if c != "disabled"]
@@ -122,7 +125,7 @@ class KeyPairsTable(tables.DataTable):
     fingerprint = tables.Column("fingerprint", verbose_name=_("Fingerprint"))
 
     def get_object_id(self, keypair):
-        return keypair.name
+        return parse.quote(keypair.name)
 
     class Meta(object):
         name = "keypairs"
