@@ -138,7 +138,8 @@ class DetailView(tabs.TabbedTableView):
         ]
         context["custom_breadcrumb"] = breadcrumb
         context["port"] = port
-        context["url"] = self.get_redirect_url()
+        context["url"] = reverse(
+            'horizon:project:networks:ports_tab', args=[port.network_id])
         context["actions"] = table.render_row_actions(port)
         return context
 
