@@ -286,15 +286,21 @@ class SecurityGroupsViewTests(test.TestCase):
             sec_group.description)
 
     @test.create_mocks({api.neutron: ('security_group_get',
-                                      'is_extension_supported')})
+                                      'is_extension_supported'),
+                        quotas: ('tenant_quota_usages',)})
     def test_detail_get(self):
         sec_group = self.security_groups.first()
+        quota_data = self.neutron_quota_usages.first()
+        self.mock_tenant_quota_usages.return_value = quota_data
         self.mock_security_group_get.return_value = sec_group
         self.mock_is_extension_supported.return_value = True
         res = self.client.get(self.detail_url)
         self.assertTemplateUsed(res, SG_DETAIL_TEMPLATE)
         self.mock_security_group_get.assert_called_once_with(
             test.IsHttpRequest(), sec_group.id)
+        self.assert_mock_multiple_calls_with_same_arguments(
+            self.mock_tenant_quota_usages, 2,
+            mock.call(test.IsHttpRequest(), targets=('security_group_rule', )))
         self.mock_is_extension_supported.assert_called_once_with(
             test.IsHttpRequest(), 'standard-attr-description')
 
@@ -562,10 +568,10 @@ class SecurityGroupsViewTests(test.TestCase):
         self.mock_security_group_list.return_value = sec_group_list
         self.mock_is_extension_supported.return_value = True
 
+        # note that 'port' is not passed
         formData = {'method': 'AddRule',
                     'id': sec_group.id,
                     'port_or_range': 'port',
-                    'port': None,
                     'rule_menu': rule.ip_protocol,
                     'cidr': rule.ip_range['cidr'],
                     'remote': 'cidr'}
@@ -602,10 +608,10 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertNoMessages()
         self.assertContains(res, "greater than or equal to")
 
+        # note that 'from_port' is not passed
         formData = {'method': 'AddRule',
                     'id': sec_group.id,
                     'port_or_range': 'range',
-                    'from_port': None,
                     'to_port': rule.to_port,
                     'rule_menu': rule.ip_protocol,
                     'cidr': rule.ip_range['cidr'],
@@ -615,11 +621,11 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertContains(res, cgi.escape('"from" port number is invalid',
                                             quote=True))
 
+        # note that 'to_port' is not passed
         formData = {'method': 'AddRule',
                     'id': sec_group.id,
                     'port_or_range': 'range',
                     'from_port': rule.from_port,
-                    'to_port': None,
                     'rule_menu': rule.ip_protocol,
                     'cidr': rule.ip_range['cidr'],
                     'remote': 'cidr'}
@@ -669,30 +675,6 @@ class SecurityGroupsViewTests(test.TestCase):
         self.assertNoMessages()
         self.assertContains(res, "The ICMP code not in range (-1, 255)")
 
-        formData = {'method': 'AddRule',
-                    'id': sec_group.id,
-                    'port_or_range': 'port',
-                    'icmp_type': icmp_rule.from_port,
-                    'icmp_code': None,
-                    'rule_menu': icmp_rule.ip_protocol,
-                    'cidr': icmp_rule.ip_range['cidr'],
-                    'remote': 'cidr'}
-        res = self.client.post(self.edit_url, formData)
-        self.assertNoMessages()
-        self.assertContains(res, "The ICMP code not in range (-1, 255)")
-
-        formData = {'method': 'AddRule',
-                    'id': sec_group.id,
-                    'port_or_range': 'port',
-                    'icmp_type': None,
-                    'icmp_code': icmp_rule.to_port,
-                    'rule_menu': icmp_rule.ip_protocol,
-                    'cidr': icmp_rule.ip_range['cidr'],
-                    'remote': 'cidr'}
-        res = self.client.post(self.edit_url, formData)
-        self.assertNoMessages()
-        self.assertContains(res, "The ICMP type not in range (-1, 255)")
-
         formData = {'method': 'AddRule',
                     'id': sec_group.id,
                     'port_or_range': 'port',
@@ -707,10 +689,10 @@ class SecurityGroupsViewTests(test.TestCase):
             res, "ICMP code is provided but ICMP type is missing.")
 
         self.assert_mock_multiple_calls_with_same_arguments(
-            self.mock_security_group_list, 10,
+            self.mock_security_group_list, 6,
             mock.call(test.IsHttpRequest()))
         self.assert_mock_multiple_calls_with_same_arguments(
-            self.mock_is_extension_supported, 10,
+            self.mock_is_extension_supported, 6,
             mock.call(test.IsHttpRequest(), 'standard-attr-description'))
 
     @test.create_mocks({api.neutron: ('security_group_rule_create',
