@@ -136,7 +136,7 @@ def _apply_panel_mocks(patchers=None):
     """Global mocks on panels that get called on all views."""
     if patchers is None:
         patchers = {}
-    mocked_methods = getattr(settings, 'TEST_GLOBAL_MOCKS_ON_PANELS', {})
+    mocked_methods = settings.TEST_GLOBAL_MOCKS_ON_PANELS
     for name, mock_config in mocked_methods.items():
         method = mock_config['method']
         mock_params = {}
@@ -542,7 +542,7 @@ def my_custom_sort(flavor):
 # Site registry touched by setUp() cleanly. As a workaround, we run
 # PluginTestCase as a separate test process. Hopefully this workaround has gone
 # in future. For more detail, see bug 1809983 and
-# https://review.openstack.org/#/c/627640/.
+# https://review.opendev.org/#/c/627640/.
 @tag('plugin-test')
 class PluginTestCase(TestCase):
     """Test case for testing plugin system of Horizon.
