@@ -13,8 +13,6 @@
 #    under the License.
 
 from cinderclient.v2 import availability_zones
-from cinderclient.v2 import cgsnapshots
-from cinderclient.v2 import consistencygroups
 from cinderclient.v2.contrib import list_extensions as cinder_list_extensions
 from cinderclient.v2 import pools
 from cinderclient.v2 import qos_specs
@@ -55,9 +53,6 @@ def data(TEST):
     TEST.cinder_availability_zones = utils.TestDataContainer()
     TEST.cinder_volume_transfers = utils.TestDataContainer()
     TEST.cinder_pools = utils.TestDataContainer()
-    TEST.cinder_consistencygroups = utils.TestDataContainer()
-    TEST.cinder_cgroup_volumes = utils.TestDataContainer()
-    TEST.cinder_cg_snapshots = utils.TestDataContainer()
     TEST.cinder_groups = utils.TestDataContainer()
     TEST.cinder_group_types = utils.TestDataContainer()
     TEST.cinder_group_snapshots = utils.TestDataContainer()
@@ -99,6 +94,7 @@ def data(TEST):
          'display_description': 'Volume description',
          'created_at': '2014-01-27 10:30:00',
          'volume_type': None,
+         'bootable': 'false',
          'attachments': []})
     nameless_volume = volumes.Volume(
         volumes.VolumeManager(None),
@@ -110,6 +106,7 @@ def data(TEST):
          "device": "/dev/hda",
          "created_at": '2010-11-21 18:34:25',
          "volume_type": 'vol_type_1',
+         'bootable': 'true',
          "attachments": []})
     other_volume = volumes.Volume(
         volumes.VolumeManager(None),
@@ -120,7 +117,9 @@ def data(TEST):
          'display_description': '',
          'created_at': '2013-04-01 10:30:00',
          'volume_type': None,
-         'attachments': [{"id": "1", "server_id": '1',
+         'bootable': 'true',
+         'attachments': [{"id": "21023e92-8008-1234-8059-7f2293ff3889",
+                          "server_id": '1',
                           "device": "/dev/hda"}]})
     volume_with_type = volumes.Volume(
         volumes.VolumeManager(None),
@@ -132,7 +131,9 @@ def data(TEST):
          'display_description': '',
          'created_at': '2013-04-01 10:30:00',
          'volume_type': 'vol_type_2',
-         'attachments': [{"id": "2", "server_id": '2',
+         'bootable': 'false',
+         'attachments': [{"id": "7dcb47fd-07d9-42c2-9647-be5eab799ebe",
+                          "server_id": '2',
                           "device": "/dev/hdb"}]})
     non_bootable_volume = volumes.Volume(
         volumes.VolumeManager(None),
@@ -143,8 +144,10 @@ def data(TEST):
          'display_description': '',
          'created_at': '2013-04-01 10:30:00',
          'volume_type': None,
+         'bootable': 'false',
          'bootable': False,
-         'attachments': [{"id": "1", "server_id": '1',
+         'attachments': [{"id": "21023e92-8008-1234-8059-7f2293ff3890",
+                          "server_id": '1',
                           "device": "/dev/hda"}]})
 
     volume.bootable = 'true'
@@ -205,6 +208,7 @@ def data(TEST):
          'display_name': 'test snapshot',
          'display_description': 'volume snapshot',
          'size': 40,
+         'created_at': '2014-01-27 10:30:00',
          'status': 'available',
          'volume_id': '11023e92-8008-4c8b-8059-7f2293ff3887'})
     snapshot2 = vol_snaps.Snapshot(
@@ -213,6 +217,7 @@ def data(TEST):
          'name': '',
          'description': 'v2 volume snapshot description',
          'size': 80,
+         'created_at': '2014-01-27 10:30:00',
          'status': 'available',
          'volume_id': '31023e92-8008-4c8b-8059-7f2293ff1234'})
     snapshot3 = vol_snaps.Snapshot(
@@ -221,6 +226,7 @@ def data(TEST):
          'name': '',
          'description': 'v2 volume snapshot description 2',
          'size': 80,
+         'created_at': '2014-01-27 10:30:00',
          'status': 'available',
          'volume_id': '31023e92-8008-4c8b-8059-7f2293ff1234'})
     snapshot4 = vol_snaps.Snapshot(
@@ -229,6 +235,7 @@ def data(TEST):
          'name': '',
          'description': 'v2 volume snapshot with metadata description',
          'size': 80,
+         'created_at': '2014-01-27 10:30:00',
          'status': 'available',
          'volume_id': '31023e92-8008-4c8b-8059-7f2293ff1234',
          'metadata': {'snapshot_meta_key': 'snapshot_meta_value'}})
@@ -270,6 +277,7 @@ def data(TEST):
          'size': 10,
          'status': 'available',
          'container_name': 'volumebackups',
+         'snapshot_id': None,
          'volume_id': '11023e92-8008-4c8b-8059-7f2293ff3887'})
 
     volume_backup2 = vol_backups.VolumeBackup(
@@ -279,6 +287,7 @@ def data(TEST):
          'description': 'volume backup 2',
          'size': 20,
          'status': 'available',
+         'snapshot_id': snapshot2.id,
          'container_name': 'volumebackups',
          'volume_id': '31023e92-8008-4c8b-8059-7f2293ff1234'})
 
@@ -288,6 +297,7 @@ def data(TEST):
          'name': 'backup3',
          'description': 'volume backup 3',
          'size': 20,
+         'snapshot_id': None,
          'status': 'available',
          'container_name': 'volumebackups',
          'volume_id': '31023e92-8008-4c8b-8059-7f2293ff1234'})
@@ -456,49 +466,6 @@ def data(TEST):
     TEST.cinder_pools.add(pool1)
     TEST.cinder_pools.add(pool2)
 
-    # volume consistency groups
-    cgroup_1 = consistencygroups.Consistencygroup(
-        consistencygroups.ConsistencygroupManager(None),
-        {'id': u'1',
-         'name': u'cg_1',
-         'description': 'cg 1 description',
-         'volume_types': ['1'],
-         'volume_type_names': []})
-
-    cgroup_2 = consistencygroups.Consistencygroup(
-        consistencygroups.ConsistencygroupManager(None),
-        {'id': u'2',
-         'name': u'cg_2',
-         'description': 'cg 2 description',
-         'volume_types': ['1'],
-         'volume_type_names': []})
-
-    TEST.cinder_consistencygroups.add(cgroup_1)
-    TEST.cinder_consistencygroups.add(cgroup_2)
-
-    volume_for_consistency_group = volumes.Volume(
-        volumes.VolumeManager(None),
-        {'id': "11023e92-8008-4c8b-8059-7f2293ff3881",
-         'status': 'available',
-         'size': 40,
-         'name': 'Volume name',
-         'display_description': 'Volume description',
-         'created_at': '2014-01-27 10:30:00',
-         'volume_type': 'vol_type_1',
-         'attachments': [],
-         'consistencygroup_id': u'1'})
-    TEST.cinder_cgroup_volumes.add(api.cinder.Volume(
-        volume_for_consistency_group))
-
-    # volume consistency group snapshots
-    cg_snapshot_1 = cgsnapshots.Cgsnapshot(
-        cgsnapshots.CgsnapshotManager(None),
-        {'id': u'1',
-         'name': u'cg_ss_1',
-         'description': 'cg_ss 1 description',
-         'consistencygroup_id': u'1'})
-    TEST.cinder_cg_snapshots.add(cg_snapshot_1)
-
     group_type_1 = group_types.GroupType(
         group_types.GroupTypeManager(None),
         {
